<img src="./python.png" width="100%" style="width:100%" />

# VoiceIt2-Python ![travisstatus](https://travis-ci.org/voiceittech/voiceit2-python.svg?branch=master)

A Python wrapper for VoiceIt's API 2.0 featuring Voice + Face Verification and Identification.

## Getting Started

Sign up for a free Developer Account at [VoiceIt.io](https://voiceit.io/signup). Visit the settings tab to view your API Key and Token. 

## API calls
You can visit our [HTTP API 2.0 Documentation](https://api.voiceit.io/?python#introduction) for detailed information on each API call.

## Support

Contact us with any questions at support@voiceit.io

## License

VoiceIt2-Python is available under the MIT license. See the LICENSE file for more info.
